GpSmartLoginInput class
Entrada de autenticación que detecta correo o teléfono automáticamente.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- GpSmartLoginInput
Constructors
-
GpSmartLoginInput({Key? key, required TextEditingController controller, ValueChanged<
String> ? onChanged, ValueChanged<GpSmartLoginValue> ? onValueChanged, FormFieldValidator<String> ? validator, GpSmartLoginMode mode = GpSmartLoginMode.auto, String initialCountryCode = 'US', bool enabled = true, bool isLoading = false, String emailHintText = 'user@example.com', String phoneHintText = '987 654 321', String emailLabelText = 'Email', String phoneLabelText = 'Phone number', String neutralLabelText = 'Email or phone'}) -
const
Properties
- controller → TextEditingController
-
final
- emailHintText → String
-
final
- emailLabelText → String
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialCountryCode → String
-
final
- isLoading → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mode → GpSmartLoginMode
-
final
- neutralLabelText → String
-
final
-
onChanged
→ ValueChanged<
String> ? -
final
-
onValueChanged
→ ValueChanged<
GpSmartLoginValue> ? -
final
- phoneHintText → String
-
final
- phoneLabelText → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
validator
→ FormFieldValidator<
String> ? -
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited