SmartLoginValue class

Constructors

SmartLoginValue({required String value, required InputType type, required String dialCode, required String countryCode, required String flagEmoji})
const

Properties

countryCode String
final
dialCode String
final
flagEmoji String
final
hashCode int
The hash code for this object.
no setterinherited
isPhone bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type InputType
final
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited