GpDateRangeSelector class

Selector de rango de fechas para filtros, reportes y dashboards.

Inheritance

Constructors

GpDateRangeSelector({Key? key, DateTimeRange<DateTime>? initialRange, required DateTime firstDate, required DateTime lastDate, void onRangeSelected(DateTimeRange<DateTime> range)?, String label = 'DATE RANGE', String emptyText = 'Select date range', String applyText = 'Apply range', String startDateText = 'Start date', String endDateText = 'End date', List<GpDateRangePreset> presets = const <GpDateRangePreset>[GpDateRangePreset(label: 'Today', resolver: _todayResolver), GpDateRangePreset(label: '7 days', resolver: _last7DaysResolver), GpDateRangePreset(label: '30 days', resolver: _last30DaysResolver), GpDateRangePreset(label: 'This month', resolver: _thisMonthResolver)]})
const

Properties

applyText String
final
emptyText String
final
endDateText String
final
firstDate DateTime
final
hashCode int
The hash code for this object.
no setterinherited
initialRange DateTimeRange<DateTime>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
final
lastDate DateTime
final
onRangeSelected → void Function(DateTimeRange<DateTime> range)?
final
presets List<GpDateRangePreset>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDateText String
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<GpDateRangeSelector>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited