GpSemanticColors class
Colores semánticos compartidos del sistema GP.
- Inheritance
-
- Object
- ThemeExtension<
GpSemanticColors> - GpSemanticColors
- Annotations
Constructors
- GpSemanticColors({required Color info, required Color onInfo, required Color infoContainer, required Color onInfoContainer, required Color success, required Color onSuccess, required Color successContainer, required Color onSuccessContainer, required Color warning, required Color onWarning, required Color warningContainer, required Color onWarningContainer, required Color danger, required Color onDanger, required Color dangerContainer, required Color onDangerContainer, required Color neutral, required Color onNeutral, required Color neutralContainer, required Color onNeutralContainer})
-
const
Properties
- danger → Color
-
final
- dangerContainer → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- info → Color
-
final
- infoContainer → Color
-
final
- neutral → Color
-
final
- neutralContainer → Color
-
final
- onDanger → Color
-
final
- onDangerContainer → Color
-
final
- onInfo → Color
-
final
- onInfoContainer → Color
-
final
- onNeutral → Color
-
final
- onNeutralContainer → Color
-
final
- onSuccess → Color
-
final
- onSuccessContainer → Color
-
final
- onWarning → Color
-
final
- onWarningContainer → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → Color
-
final
- successContainer → Color
-
final
- type → Object
-
The extension's type.
no setterinherited
- warning → Color
-
final
- warningContainer → Color
-
final
Methods
-
copyWith(
{Color? info, Color? onInfo, Color? infoContainer, Color? onInfoContainer, Color? success, Color? onSuccess, Color? successContainer, Color? onSuccessContainer, Color? warning, Color? onWarning, Color? warningContainer, Color? onWarningContainer, Color? danger, Color? onDanger, Color? dangerContainer, Color? onDangerContainer, Color? neutral, Color? onNeutral, Color? neutralContainer, Color? onNeutralContainer}) → GpSemanticColors -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< GpSemanticColors> ? other, double t) → GpSemanticColors -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited