GpTextSize class
Escala tipográfica base del sistema GP.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
large(
[BuildContext? _]) → double -
medium(
[BuildContext? _]) → double -
small(
[BuildContext? _]) → double -
xLarge(
[BuildContext? _]) → double -
xSmall(
[BuildContext? _]) → double -
xxLarge(
[BuildContext? _]) → double
Constants
- largeValue → const double
- mediumValue → const double
- smallValue → const double
- xLargeValue → const double
- xSmallValue → const double
- xxLargeValue → const double