GpTextarea class
Campo multilinea del sistema GP con integración a Form.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- GpTextarea
Constructors
- GpTextarea({Key? key, String hintText = '', TextEditingController? controller, AutovalidateMode autovalidateMode = AutovalidateMode.onUserInteraction, Color? borderColor, Color? focusedBorderColor, Color? errorBorderColor, double? borderRadius, GpComponentSize size = GpComponentSize.md, TextStyle? textStyle, TextStyle? hintStyle, bool disabled = false, bool readOnly = false, int minLines = 4, int maxLines = 6, void onTap()?, String? validator(String?)?, void onFieldSubmitted(String)?, void onChanged(String)?, String? label, String? helperText, FocusNode? focusNode})
-
const
Properties
- autovalidateMode → AutovalidateMode
-
final
- borderColor → Color?
-
final
- borderRadius → double?
-
final
- controller → TextEditingController?
-
final
- disabled → bool
-
final
- errorBorderColor → Color?
-
final
- focusedBorderColor → Color?
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
final
- hintStyle → TextStyle?
-
final
- hintText → String
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
- maxLines → int
-
final
- minLines → int
-
final
- onChanged → void Function(String)?
-
final
- onFieldSubmitted → void Function(String)?
-
final
- onTap → void Function()?
-
final
- readOnly → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → GpComponentSize
-
final
- textStyle → TextStyle?
-
final
- validator → String? Function(String?)?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited