GpApiResponse<T> class

Resultado estándar de una petición

Constructors

GpApiResponse.error(String message, {int? statusCode})
factory
GpApiResponse.success(T data, {int? statusCode})
factory

Properties

data → T?
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited