GpHttpHelpers class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dataOf<T>(Response<T> response) → T?
extractGpException(Object error) GpException?
getData<T>(T? data) → T?
requireData<T>(Response<T> response, {String message = 'La respuesta no contiene datos.'}) → T