GpRetryOptions class

Constructors

GpRetryOptions({int maxRetries = 2, Duration retryDelay = const Duration(milliseconds: 400), bool exponentialBackoff = true, Set<int> retryStatusCodes = const {408, 429, 500, 502, 503, 504}, Set<DioExceptionType> retryOn = const {DioExceptionType.connectionTimeout, DioExceptionType.receiveTimeout, DioExceptionType.sendTimeout, DioExceptionType.connectionError}, Set<String> retryMethods = const {'GET', 'HEAD', 'OPTIONS'}})
const

Properties

exponentialBackoff bool
final
hashCode int
The hash code for this object.
no setterinherited
maxRetries int
final
retryDelay Duration
final
retryMethods Set<String>
final
retryOn Set<DioExceptionType>
final
retryStatusCodes Set<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited