GpProfileDocumentConfig class

Constructors

GpProfileDocumentConfig({String hintText = 'Document number', TextInputType keyboardType = TextInputType.number, String? validator(String?)?, List<TextInputFormatter>? inputFormatters, String? helperText, int? maxLength})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
helperText String?
final
hintText String
final
inputFormatters List<TextInputFormatter>?
final
keyboardType TextInputType
final
maxLength int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validator String? Function(String?)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited