GpProfileDocumentSelector class

Selector compuesto de tipo y número de documento para perfil.

Inheritance

Constructors

GpProfileDocumentSelector({Key? key, required List<String> docTypes, required String selectedDocType, required ValueChanged<String> onDocTypeSelected, required TextEditingController controller, Color? borderColor, Color? highlightColor, Color? backgroundColor, Map<String, GpProfileDocumentConfig> documentConfigs = const {}, ValueChanged<String>? onChanged, String? errorText, bool enabled = true, bool readOnly = false})
const

Properties

backgroundColor Color?
final
borderColor Color?
final
controller TextEditingController
final
docTypes List<String>
final
documentConfigs Map<String, GpProfileDocumentConfig>
final
enabled bool
final
errorText String?
final
hashCode int
The hash code for this object.
no setterinherited
highlightColor Color?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged ValueChanged<String>?
final
onDocTypeSelected ValueChanged<String>
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedDocType String
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited