GpValidators class

Validadores reutilizables para formularios GP Puedes importar este archivo desde tu app y usar los métodos estáticos.

Constructors

GpValidators()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

combine(List<String? Function(String?)> validators) String? Function(String?)
minLength(int min, {String? message}) String? Function(String?)
validateEmail(String? value, {String? message}) String?
validateMatchingPasswords(String? value, String password, {String? message}) String?
validateNumber(String? value, {String? message}) String?
validateRequired(String? value, {String? message}) String?
validateServiceId(String? value, {String? message}) String?