GpSurfaceThemeData class
Defaults visuales compartidos para badges, feedback y superficies de acción.
- Inheritance
-
- Object
- ThemeExtension<
GpSurfaceThemeData> - GpSurfaceThemeData
- Annotations
Constructors
- GpSurfaceThemeData({TextStyle? badgeTextStyle, TextStyle? bannerTitleStyle, TextStyle? bannerMessageStyle, TextStyle? inlineTitleStyle, TextStyle? inlineMessageStyle, TextStyle? actionTitleStyle, TextStyle? actionSubtitleStyle, TextStyle? toastTitleStyle, TextStyle? toastSubtitleStyle, TextStyle? statusTitleStyle, TextStyle? statusMessageStyle, Color? borderColor, Color? shadowColor, double badgeBorderRadius = 999, double panelBorderRadius = 16, double shadowBlurRadius = 8, Offset shadowOffset = const Offset(0, 4), double shadowAlpha = 0.05, double subtleBorderAlpha = 0.14})
-
const
Properties
- actionSubtitleStyle → TextStyle?
-
final
- actionTitleStyle → TextStyle?
-
final
- badgeBorderRadius → double
-
final
- badgeTextStyle → TextStyle?
-
final
-
final
-
final
- borderColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inlineMessageStyle → TextStyle?
-
final
- inlineTitleStyle → TextStyle?
-
final
- panelBorderRadius → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowAlpha → double
-
final
- shadowBlurRadius → double
-
final
- shadowColor → Color?
-
final
- shadowOffset → Offset
-
final
- statusMessageStyle → TextStyle?
-
final
- statusTitleStyle → TextStyle?
-
final
- subtleBorderAlpha → double
-
final
- toastSubtitleStyle → TextStyle?
-
final
- toastTitleStyle → TextStyle?
-
final
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{TextStyle? badgeTextStyle, TextStyle? bannerTitleStyle, TextStyle? bannerMessageStyle, TextStyle? inlineTitleStyle, TextStyle? inlineMessageStyle, TextStyle? actionTitleStyle, TextStyle? actionSubtitleStyle, TextStyle? toastTitleStyle, TextStyle? toastSubtitleStyle, TextStyle? statusTitleStyle, TextStyle? statusMessageStyle, Color? borderColor, Color? shadowColor, double? badgeBorderRadius, double? panelBorderRadius, double? shadowBlurRadius, Offset? shadowOffset, double? shadowAlpha, double? subtleBorderAlpha}) → GpSurfaceThemeData -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< GpSurfaceThemeData> ? other, double t) → GpSurfaceThemeData -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited